marktools.BendAfter
===================

.. inheritance-diagram:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter
   :private-bases:

.. autoclass:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.lilypond_format

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.bend_amount

Methods
-------

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.attach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.detach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__eq__

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.BendAfter.BendAfter.BendAfter.__str__
